==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicListUI__24ListSelectionHandler.h <==
// class javax.swing.plaf.basic.BasicListUI$ListSelectionHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 934d967307ac2fec javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler_H_
#define _JC_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_event_ListSelectionEvent$object;
struct _jc_javax_swing_plaf_basic_BasicListUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$refs	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$object	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vmethods	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vtable	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vtype	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$method$_init$8a1f9d7ba661b1c8(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$object *, struct _jc_javax_swing_plaf_basic_BasicListUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$method$valueChanged$f360df5a43a62b7d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$object *, struct _jc_javax_swing_event_ListSelectionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$method_info$valueChanged$f360df5a43a62b7d;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vmethods {
	void	(*valueChanged$f360df5a43a62b7d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$object *, struct _jc_javax_swing_event_ListSelectionEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vmethods	javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicListUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$refs {
    _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$sub_refs	javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$sub_nonrefs	javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$object {
	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vtype _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicListUI__24ListSelectionHandler.h <==
// public class javax.swing.plaf.basic.BasicListUI$ListSelectionHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 69c5952d6e3a13ab javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler_H_
#define _JC_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_event_ListSelectionEvent$object;
struct _jc_javax_swing_plaf_basic_BasicListUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$refs	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$object	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vmethods	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vtable	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vtype	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$method$_init$8a1f9d7ba661b1c8(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$object *, struct _jc_javax_swing_plaf_basic_BasicListUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$method$valueChanged$f360df5a43a62b7d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$object *, struct _jc_javax_swing_event_ListSelectionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$method_info$valueChanged$f360df5a43a62b7d;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vmethods {
	void	(*valueChanged$f360df5a43a62b7d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$object *, struct _jc_javax_swing_event_ListSelectionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vmethods	javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicListUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$refs {
    _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$sub_refs	javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$sub_nonrefs	javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$object {
	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$vtype _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicListUI__24ListSelectionHandler_H_ */
